==> alipay-sdk-python-3.6.371.tar.gz: alipay-sdk-python-3.6.371/alipay/aop/api/domain/AlipayCommerceOperationTimescardOrderBatchqueryModel.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationTimescardOrderBatchqueryModel(object):

    def __init__(self):
        self._item_id = None
        self._order_time_end = None
        self._order_time_start = None
        self._page_num = None
        self._page_size = None
        self._scene_code = None
        self._user_id = None

    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def order_time_end(self):
        return self._order_time_end

    @order_time_end.setter
    def order_time_end(self, value):
        self._order_time_end = value
    @property
    def order_time_start(self):
        return self._order_time_start

    @order_time_start.setter
    def order_time_start(self, value):
        self._order_time_start = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.order_time_end:
            if hasattr(self.order_time_end, 'to_alipay_dict'):
                params['order_time_end'] = self.order_time_end.to_alipay_dict()
            else:
                params['order_time_end'] = self.order_time_end
        if self.order_time_start:
            if hasattr(self.order_time_start, 'to_alipay_dict'):
                params['order_time_start'] = self.order_time_start.to_alipay_dict()
            else:
                params['order_time_start'] = self.order_time_start
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationTimescardOrderBatchqueryModel()
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'order_time_end' in d:
            o.order_time_end = d['order_time_end']
        if 'order_time_start' in d:
            o.order_time_start = d['order_time_start']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o

==> alipay-sdk-python-3.7.78.tar.gz: alipay-sdk-python-3.7.78/alipay/aop/api/domain/AlipayCommerceOperationTimescardOrderBatchqueryModel.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationTimescardOrderBatchqueryModel(object):

    def __init__(self):
        self._item_id = None
        self._open_id = None
        self._order_time_end = None
        self._order_time_start = None
        self._page_num = None
        self._page_size = None
        self._scene_code = None
        self._user_id = None

    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_time_end(self):
        return self._order_time_end

    @order_time_end.setter
    def order_time_end(self, value):
        self._order_time_end = value
    @property
    def order_time_start(self):
        return self._order_time_start

    @order_time_start.setter
    def order_time_start(self, value):
        self._order_time_start = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.order_time_end:
            if hasattr(self.order_time_end, 'to_alipay_dict'):
                params['order_time_end'] = self.order_time_end.to_alipay_dict()
            else:
                params['order_time_end'] = self.order_time_end
        if self.order_time_start:
            if hasattr(self.order_time_start, 'to_alipay_dict'):
                params['order_time_start'] = self.order_time_start.to_alipay_dict()
            else:
                params['order_time_start'] = self.order_time_start
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationTimescardOrderBatchqueryModel()
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'order_time_end' in d:
            o.order_time_end = d['order_time_end']
        if 'order_time_start' in d:
            o.order_time_start = d['order_time_start']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o
